@@ -23,8 +23,8 @@
 from .version import __version__
 
 from .gummy import gummy,jummy
-from .unit import Unit,Conversion,one
-from .ummy import ummy, MFraction
+from .unit import Unit,Conversion,one,Quantity,QuantityArray,unit
+from .ummy import ummy,immy,MFraction
 from .budget import Budget
 from .prefixedunit import PrefixedUnit,BinaryPrefixedUnit
 from .nonlinearunit import NonlinearUnit,NonlinearConversion
@@ -36,4 +36,6 @@ from .fit import *
 from .distributions import *
 from .exceptions import *
 from .printing import set_printer
-from .unitutils import search_units,shadowed_units,convert
\ No newline at end of file
+from .unitutils import search_units,shadowed_units,convert
+from .constant import (GummyConstant,JummyConstant,constant,search_constants,
+                       shadowed_constants)
\ No newline at end of file
