@@ -27,6 +27,7 @@ units.
 
 import numpy as np
 from .unit import one,_CompositeUnit,Quantity
+from .ummy import ummy
 from .nonlinearunit import NonlinearConversion,NonlinearUnit
 from .exceptions import IncompatibleUnitsError
 
@@ -35,17 +36,32 @@ class LogConversion(NonlinearConversion):
         if isinstance(reference,Quantity):
             self._unit = reference.unit
             self._rf = reference.value
+            if self._unit.is_dimensionless:
+                self._dim = False
+            else:
+                self._dim = True
         else:
             self._unit = one
             self._rf = reference
+            self._dim = False
     
         self.reference = reference
         
         self.multiplier = multiplier           
         self.log_base = log_base
-        self.log_func = lambda x: log_func(x) if x > 0 else -float('inf')
+        self._log_func = log_func
         self._lnbase = np.log(log_base)
         self.offset = offset
+    
+    def log_func(self,x):
+        if isinstance(x,Quantity):
+            x = x.value
+            if isinstance(x,ummy):
+                x = x.x
+            if x <= 0:
+                return type(x)(-float('inf'))
+            
+        return self._log_func(x)
         
     def to(self,g):
         g = (g - self.offset)/self.multiplier
@@ -91,26 +107,40 @@ class LogUnit(NonlinearUnit):
         return -float('inf')
     
     def _add(self,a,bunit,b,aconv):
+        if self.conversion._dim:
+            raise IncompatibleUnitsError('operation not allowed with unit ' + self.tostring())
         if bunit is not self:
             raise IncompatibleUnitsError('a quantity with unit ' + self.tostring() + ' may not be added to a quantity with unit ' + bunit.tostring() + '; automatic conversion is disabled with LogUnit instances')
         return (a + b,self)
     
     def _radd(self,a,bunit,b,aconv):
+        if self.conversion._dim:
+            raise IncompatibleUnitsError('operation not allowed with unit ' + self.tostring())
+
         if bunit is not self:
             raise IncompatibleUnitsError('a quantity with unit ' + self.tostring() + ' may not be added to a quantity with unit ' + bunit.tostring() + '; automatic conversion is disabled with LogUnit instances')
         return (b + a,self)
     
     def _sub(self,a,bunit,b,aconv):
+        if self.conversion._dim:
+            raise IncompatibleUnitsError('operation not allowed with unit ' + self.tostring())
+
         if bunit is not self:
             raise IncompatibleUnitsError('a quantity with unit ' + bunit.tostring() + ' may not be subtracted from a quantity with unit ' + self.tostring() + '; automatic conversion is disabled with LogUnit instances')
         return (a - b,self)
     
     def _rsub(self,a,bunit,b,aconv):
+        if self.conversion._dim:
+            raise IncompatibleUnitsError('operation not allowed with unit ' + self.tostring())
+
         if bunit is not self:
             raise IncompatibleUnitsError('a quantity with unit ' + self.tostring() + ' may not be subtracted from a quantity with unit ' + bunit.tostring() + '; automatic conversion is disabled with LogUnit instances')
         return (a + b,self)
     
     def _mul(self,a,bunit,b,aconv):
+        if self.conversion._dim:
+            raise IncompatibleUnitsError('operation not allowed with unit ' + self.tostring())
+
         if not bunit.linear:
             raise IncompatibleUnitsError('only quantities with linear units may multiply or divide a quanity with unit ' + self.tostring())
         
@@ -122,6 +152,9 @@ class LogUnit(NonlinearUnit):
         return ((a*b)*c,un)
     
     def _rmul(self,a,bunit,b,aconv):
+        if self.conversion._dim:
+            raise IncompatibleUnitsError('operation not allowed with unit ' + self.tostring())
+
         if not bunit.linear:
             raise IncompatibleUnitsError('only quantities with linear units may multiply or divide a quanity with unit ' + self.tostring())
         
@@ -133,6 +166,9 @@ class LogUnit(NonlinearUnit):
         return ((b*a)*c,un)
     
     def _truediv(self,a,bunit,b,aconv):
+        if self.conversion._dim:
+            raise IncompatibleUnitsError('operation not allowed with unit ' + self.tostring())
+
         if not bunit.linear:
             raise IncompatibleUnitsError('only quantities with linear units may multiply or divide a quanity with unit ' + self.tostring())
         
